@@ -1,9 +1,10 @@
+//go:build !linux || exclude_disk_quota || !cgo
 // +build !linux exclude_disk_quota !cgo
 
 package quota
 
 import (
-	"github.com/pkg/errors"
+	"errors"
 )
 
 // Quota limit params - currently we only control blocks hard limit
