@@ -5,7 +5,7 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
+	"net"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -109,7 +109,7 @@ func testDecompressStream(t *testing.T, ext, compressCommand string) {
 	if err != nil {
 		t.Fatalf("Failed to decompress %s: %v", filename, err)
 	}
-	if _, err = ioutil.ReadAll(r); err != nil {
+	if _, err = io.ReadAll(r); err != nil {
 		t.Fatalf("Failed to read the decompressed stream: %v ", err)
 	}
 	if err = r.Close(); err != nil {
@@ -209,9 +209,7 @@ func TestExtensionXz(t *testing.T) {
 }
 
 func TestUntarPathWithInvalidDest(t *testing.T) {
-	tempFolder, err := ioutil.TempDir("", "storage-archive-test")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempFolder)
+	tempFolder := t.TempDir()
 	invalidDestFolder := filepath.Join(tempFolder, "invalidDest")
 	// Create a src file
 	srcFile := filepath.Join(tempFolder, "src")
@@ -228,7 +226,7 @@ func TestUntarPathWithInvalidDest(t *testing.T) {
 	}
 
 	cmd := exec.Command("sh", "-c", "tar cf "+tarFileU+" "+srcFileU)
-	_, err = cmd.CombinedOutput()
+	_, err := cmd.CombinedOutput()
 	require.NoError(t, err)
 
 	err = defaultUntarPath(tarFile, invalidDestFolder)
@@ -238,27 +236,21 @@ func TestUntarPathWithInvalidDest(t *testing.T) {
 }
 
 func TestUntarPathWithInvalidSrc(t *testing.T) {
-	dest, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatalf("Fail to create the destination file")
-	}
-	defer os.RemoveAll(dest)
-	err = defaultUntarPath("/invalid/path", dest)
+	dest := t.TempDir()
+	err := defaultUntarPath("/invalid/path", dest)
 	if err == nil {
 		t.Fatalf("UntarPath with invalid src path should throw an error.")
 	}
 }
 
 func TestUntarPath(t *testing.T) {
-	tmpFolder, err := ioutil.TempDir("", "storage-archive-test")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpFolder)
+	tmpFolder := t.TempDir()
 	srcFile := filepath.Join(tmpFolder, "src")
 	tarFile := filepath.Join(tmpFolder, "src.tar")
 	os.Create(filepath.Join(tmpFolder, "src"))
 
 	destFolder := filepath.Join(tmpFolder, "dest")
-	err = os.MkdirAll(destFolder, 0740)
+	err := os.MkdirAll(destFolder, 0740)
 	if err != nil {
 		t.Fatalf("Fail to create the destination file")
 	}
@@ -287,11 +279,7 @@ func TestUntarPath(t *testing.T) {
 
 // Do the same test as above but with the destination as file, it should fail
 func TestUntarPathWithDestinationFile(t *testing.T) {
-	tmpFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tmpFolder)
+	tmpFolder := t.TempDir()
 	srcFile := filepath.Join(tmpFolder, "src")
 	tarFile := filepath.Join(tmpFolder, "src.tar")
 	os.Create(filepath.Join(tmpFolder, "src"))
@@ -304,7 +292,7 @@ func TestUntarPathWithDestinationFile(t *testing.T) {
 		srcFileU = "/tmp/" + filepath.Base(filepath.Dir(srcFile)) + "/src"
 	}
 	cmd := exec.Command("sh", "-c", "tar cf "+tarFileU+" "+srcFileU)
-	_, err = cmd.CombinedOutput()
+	_, err := cmd.CombinedOutput()
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -323,11 +311,7 @@ func TestUntarPathWithDestinationFile(t *testing.T) {
 // and the destination file is a directory
 // It's working, see https://github.com/docker/docker/issues/10040
 func TestUntarPathWithDestinationSrcFileAsFolder(t *testing.T) {
-	tmpFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tmpFolder)
+	tmpFolder := t.TempDir()
 	srcFile := filepath.Join(tmpFolder, "src")
 	tarFile := filepath.Join(tmpFolder, "src.tar")
 	os.Create(srcFile)
@@ -341,7 +325,7 @@ func TestUntarPathWithDestinationSrcFileAsFolder(t *testing.T) {
 	}
 
 	cmd := exec.Command("sh", "-c", "tar cf "+tarFileU+" "+srcFileU)
-	_, err = cmd.CombinedOutput()
+	_, err := cmd.CombinedOutput()
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -363,13 +347,10 @@ func TestUntarPathWithDestinationSrcFileAsFolder(t *testing.T) {
 }
 
 func TestCopyWithTarInvalidSrc(t *testing.T) {
-	tempFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(nil)
-	}
+	tempFolder := t.TempDir()
 	destFolder := filepath.Join(tempFolder, "dest")
 	invalidSrc := filepath.Join(tempFolder, "doesnotexists")
-	err = os.MkdirAll(destFolder, 0740)
+	err := os.MkdirAll(destFolder, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -380,13 +361,10 @@ func TestCopyWithTarInvalidSrc(t *testing.T) {
 }
 
 func TestCopyWithTarInexistentDestWillCreateIt(t *testing.T) {
-	tempFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(nil)
-	}
+	tempFolder := t.TempDir()
 	srcFolder := filepath.Join(tempFolder, "src")
 	inexistentDestFolder := filepath.Join(tempFolder, "doesnotexists")
-	err = os.MkdirAll(srcFolder, 0740)
+	err := os.MkdirAll(srcFolder, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -402,15 +380,11 @@ func TestCopyWithTarInexistentDestWillCreateIt(t *testing.T) {
 
 // Test CopyWithTar with a file as src
 func TestCopyWithTarSrcFile(t *testing.T) {
-	folder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(folder)
+	folder := t.TempDir()
 	dest := filepath.Join(folder, "dest")
 	srcFolder := filepath.Join(folder, "src")
 	src := filepath.Join(folder, filepath.Join("src", "src"))
-	err = os.MkdirAll(srcFolder, 0740)
+	err := os.MkdirAll(srcFolder, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -418,7 +392,7 @@ func TestCopyWithTarSrcFile(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	err = ioutil.WriteFile(src, []byte("content"), 0777)
+	err = os.WriteFile(src, []byte("content"), 0777)
 	if err != nil {
 		t.Fatalf("archiver.CopyWithTar couldn't write content, %s.", err)
 	}
@@ -436,7 +410,7 @@ func TestCopyWithTarSrcFile(t *testing.T) {
 	if err != nil {
 		t.Fatalf("archiver.CopyWithTar shouldn't have thrown an error, %s.", err)
 	}
-	err = ioutil.WriteFile(dest, []byte("modified content"), 0751)
+	err = os.WriteFile(dest, []byte("modified content"), 0751)
 	if err != nil {
 		t.Fatalf("archiver.CopyWithTar couldn't write modified content, %s.", err)
 	}
@@ -468,14 +442,10 @@ func TestCopyWithTarSrcFile(t *testing.T) {
 
 // Test CopyWithTar with a folder as src
 func TestCopyWithTarSrcFolder(t *testing.T) {
-	folder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(folder)
+	folder := t.TempDir()
 	dest := filepath.Join(folder, "dest")
 	src := filepath.Join(folder, filepath.Join("src", "folder"))
-	err = os.MkdirAll(src, 0740)
+	err := os.MkdirAll(src, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -483,7 +453,7 @@ func TestCopyWithTarSrcFolder(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	ioutil.WriteFile(filepath.Join(src, "file"), []byte("content"), 0777)
+	os.WriteFile(filepath.Join(src, "file"), []byte("content"), 0777)
 	err = defaultCopyWithTar(src, dest)
 	if err != nil {
 		t.Fatalf("archiver.CopyWithTar shouldn't throw an error, %s.", err)
@@ -496,13 +466,9 @@ func TestCopyWithTarSrcFolder(t *testing.T) {
 }
 
 func TestCopyFileWithTarInvalidSrc(t *testing.T) {
-	tempFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tempFolder)
+	tempFolder := t.TempDir()
 	destFolder := filepath.Join(tempFolder, "dest")
-	err = os.MkdirAll(destFolder, 0740)
+	err := os.MkdirAll(destFolder, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -514,14 +480,10 @@ func TestCopyFileWithTarInvalidSrc(t *testing.T) {
 }
 
 func TestCopyFileWithTarInexistentDestWillCreateIt(t *testing.T) {
-	tempFolder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(nil)
-	}
-	defer os.RemoveAll(tempFolder)
+	tempFolder := t.TempDir()
 	srcFile := filepath.Join(tempFolder, "src")
 	inexistentDestFolder := filepath.Join(tempFolder, "doesnotexists")
-	_, err = os.Create(srcFile)
+	_, err := os.Create(srcFile)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -537,14 +499,10 @@ func TestCopyFileWithTarInexistentDestWillCreateIt(t *testing.T) {
 }
 
 func TestCopyFileWithTarSrcFolder(t *testing.T) {
-	folder, err := ioutil.TempDir("", "storage-archive-copyfilewithtar-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(folder)
+	folder := t.TempDir()
 	dest := filepath.Join(folder, "dest")
 	src := filepath.Join(folder, "srcfolder")
-	err = os.MkdirAll(src, 0740)
+	err := os.MkdirAll(src, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -559,15 +517,11 @@ func TestCopyFileWithTarSrcFolder(t *testing.T) {
 }
 
 func TestCopyFileWithTarSrcFile(t *testing.T) {
-	folder, err := ioutil.TempDir("", "storage-archive-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(folder)
+	folder := t.TempDir()
 	dest := filepath.Join(folder, "dest")
 	srcFolder := filepath.Join(folder, "src")
 	src := filepath.Join(folder, filepath.Join("src", "src"))
-	err = os.MkdirAll(srcFolder, 0740)
+	err := os.MkdirAll(srcFolder, 0740)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -575,7 +529,36 @@ func TestCopyFileWithTarSrcFile(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	ioutil.WriteFile(src, []byte("content"), 0777)
+	os.WriteFile(src, []byte("content"), 0777)
+	err = defaultCopyWithTar(src, dest+"/")
+	if err != nil {
+		t.Fatalf("archiver.CopyFileWithTar shouldn't throw an error, %s.", err)
+	}
+	_, err = os.Stat(dest)
+	if err != nil {
+		t.Fatalf("Destination folder should contain the source file but did not.")
+	}
+}
+
+func TestCopySocket(t *testing.T) {
+	folder := t.TempDir()
+	dest := filepath.Join(folder, "dest")
+	src := filepath.Join(folder, "src")
+	err := os.MkdirAll(src, 0740)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	_, err = net.Listen("unix", filepath.Join(src, "unix-socket"))
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	err = os.MkdirAll(dest, 0740)
+	if err != nil {
+		t.Fatal(err)
+	}
+	os.WriteFile(src, []byte("content"), 0777)
 	err = defaultCopyWithTar(src, dest+"/")
 	if err != nil {
 		t.Fatalf("archiver.CopyFileWithTar shouldn't throw an error, %s.", err)
@@ -592,29 +575,20 @@ func TestTarFiles(t *testing.T) {
 		t.Skip("Failing on Windows")
 	}
 	// try without hardlinks
-	if err := checkNoChanges(1000, false); err != nil {
+	if err := checkNoChanges(t, 1000, false); err != nil {
 		t.Fatal(err)
 	}
 	// try with hardlinks
-	if err := checkNoChanges(1000, true); err != nil {
+	if err := checkNoChanges(t, 1000, true); err != nil {
 		t.Fatal(err)
 	}
 }
 
-func checkNoChanges(fileNum int, hardlinks bool) error {
-	srcDir, err := ioutil.TempDir("", "storage-test-srcDir")
-	if err != nil {
-		return err
-	}
-	defer os.RemoveAll(srcDir)
+func checkNoChanges(t *testing.T, fileNum int, hardlinks bool) error {
+	srcDir := t.TempDir()
+	destDir := t.TempDir()
 
-	destDir, err := ioutil.TempDir("", "storage-test-destDir")
-	if err != nil {
-		return err
-	}
-	defer os.RemoveAll(destDir)
-
-	_, err = prepareUntarSourceDirectory(fileNum, srcDir, hardlinks)
+	_, err := prepareUntarSourceDirectory(fileNum, srcDir, hardlinks)
 	if err != nil {
 		return err
 	}
@@ -650,14 +624,10 @@ func tarUntar(t *testing.T, origin string, options *TarOptions) ([]Change, error
 	detectedCompression := DetectCompression(buf)
 	compression := options.Compression
 	if detectedCompression.Extension() != compression.Extension() {
-		return nil, fmt.Errorf("Wrong compression detected. Actual compression: %s, found %s", compression.Extension(), detectedCompression.Extension())
+		return nil, fmt.Errorf("wrong compression detected. Actual compression: %s, found %s", compression.Extension(), detectedCompression.Extension())
 	}
 
-	tmp, err := ioutil.TempDir("", "storage-test-untar")
-	if err != nil {
-		return nil, err
-	}
-	defer os.RemoveAll(tmp)
+	tmp := t.TempDir()
 	if err := Untar(wrap, tmp, nil); err != nil {
 		return nil, err
 	}
@@ -673,18 +643,14 @@ func TestTarUntar(t *testing.T) {
 	if runtime.GOOS == windows {
 		t.Skip("Failing on Windows")
 	}
-	origin, err := ioutil.TempDir("", "storage-test-untar-origin")
-	if err != nil {
+	origin := t.TempDir()
+	if err := os.WriteFile(filepath.Join(origin, "1"), []byte("hello world"), 0700); err != nil {
 		t.Fatal(err)
 	}
-	defer os.RemoveAll(origin)
-	if err := ioutil.WriteFile(filepath.Join(origin, "1"), []byte("hello world"), 0700); err != nil {
+	if err := os.WriteFile(filepath.Join(origin, "2"), []byte("welcome!"), 0700); err != nil {
 		t.Fatal(err)
 	}
-	if err := ioutil.WriteFile(filepath.Join(origin, "2"), []byte("welcome!"), 0700); err != nil {
-		t.Fatal(err)
-	}
-	if err := ioutil.WriteFile(filepath.Join(origin, "3"), []byte("will be ignored"), 0700); err != nil {
+	if err := os.WriteFile(filepath.Join(origin, "3"), []byte("will be ignored"), 0700); err != nil {
 		t.Fatal(err)
 	}
 
@@ -708,12 +674,9 @@ func TestTarUntar(t *testing.T) {
 }
 
 func TestTarWithOptionsChownOptsAlwaysOverridesIdPair(t *testing.T) {
-	origin, err := ioutil.TempDir("", "storage-test-tar-chown-opt")
-	require.NoError(t, err)
-
-	defer os.RemoveAll(origin)
+	origin := t.TempDir()
 	filePath := filepath.Join(origin, "1")
-	err = ioutil.WriteFile(filePath, []byte("hello world"), 0700)
+	err := os.WriteFile(filePath, []byte("hello world"), 0700)
 	require.NoError(t, err)
 
 	idMaps := []idtools.IDMap{
@@ -763,18 +726,14 @@ func TestTarWithOptions(t *testing.T) {
 	if runtime.GOOS == windows {
 		t.Skip("Failing on Windows")
 	}
-	origin, err := ioutil.TempDir("", "storage-test-untar-origin")
-	if err != nil {
+	origin := t.TempDir()
+	if _, err := os.MkdirTemp(origin, "folder"); err != nil {
 		t.Fatal(err)
 	}
-	if _, err := ioutil.TempDir(origin, "folder"); err != nil {
+	if err := os.WriteFile(filepath.Join(origin, "1"), []byte("hello world"), 0700); err != nil {
 		t.Fatal(err)
 	}
-	defer os.RemoveAll(origin)
-	if err := ioutil.WriteFile(filepath.Join(origin, "1"), []byte("hello world"), 0700); err != nil {
-		t.Fatal(err)
-	}
-	if err := ioutil.WriteFile(filepath.Join(origin, "2"), []byte("welcome!"), 0700); err != nil {
+	if err := os.WriteFile(filepath.Join(origin, "2"), []byte("welcome!"), 0700); err != nil {
 		t.Fatal(err)
 	}
 
@@ -805,13 +764,9 @@ func TestTarWithOptions(t *testing.T) {
 // Failing prevents the archives from being uncompressed during ADD
 func TestTypeXGlobalHeaderDoesNotFail(t *testing.T) {
 	hdr := tar.Header{Typeflag: tar.TypeXGlobalHeader}
-	tmpDir, err := ioutil.TempDir("", "storage-test-archive-pax-test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tmpDir)
+	tmpDir := t.TempDir()
 	buffer := make([]byte, 1<<20)
-	err = createTarFile(filepath.Join(tmpDir, "pax_global_header"), tmpDir, &hdr, nil, true, nil, false, false, nil, buffer)
+	err := createTarFile(filepath.Join(tmpDir, "pax_global_header"), tmpDir, &hdr, nil, true, nil, false, false, nil, buffer)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -852,7 +807,7 @@ func prepareUntarSourceDirectory(numberOfFiles int, targetPath string, makeLinks
 	fileData := []byte("fooo")
 	for n := 0; n < numberOfFiles; n++ {
 		fileName := fmt.Sprintf("file-%d", n)
-		if err := ioutil.WriteFile(filepath.Join(targetPath, fileName), fileData, 0700); err != nil {
+		if err := os.WriteFile(filepath.Join(targetPath, fileName), fileData, 0700); err != nil {
 			return 0, err
 		}
 		if makeLinks {
@@ -866,21 +821,13 @@ func prepareUntarSourceDirectory(numberOfFiles int, targetPath string, makeLinks
 }
 
 func BenchmarkTarUntar(b *testing.B) {
-	origin, err := ioutil.TempDir("", "storage-test-untar-origin")
-	if err != nil {
-		b.Fatal(err)
-	}
-	tempDir, err := ioutil.TempDir("", "storage-test-untar-destination")
-	if err != nil {
-		b.Fatal(err)
-	}
+	origin := b.TempDir()
+	tempDir := b.TempDir()
 	target := filepath.Join(tempDir, "dest")
 	n, err := prepareUntarSourceDirectory(100, origin, false)
 	if err != nil {
 		b.Fatal(err)
 	}
-	defer os.RemoveAll(origin)
-	defer os.RemoveAll(tempDir)
 
 	b.ResetTimer()
 	b.SetBytes(int64(n))
@@ -894,21 +841,13 @@ func BenchmarkTarUntar(b *testing.B) {
 }
 
 func BenchmarkTarUntarWithLinks(b *testing.B) {
-	origin, err := ioutil.TempDir("", "storage-test-untar-origin")
-	if err != nil {
-		b.Fatal(err)
-	}
-	tempDir, err := ioutil.TempDir("", "storage-test-untar-destination")
-	if err != nil {
-		b.Fatal(err)
-	}
+	origin := b.TempDir()
+	tempDir := b.TempDir()
 	target := filepath.Join(tempDir, "dest")
 	n, err := prepareUntarSourceDirectory(100, origin, true)
 	if err != nil {
 		b.Fatal(err)
 	}
-	defer os.RemoveAll(origin)
-	defer os.RemoveAll(tempDir)
 
 	b.ResetTimer()
 	b.SetBytes(int64(n))
@@ -921,6 +860,26 @@ func BenchmarkTarUntarWithLinks(b *testing.B) {
 	}
 }
 
+func TestUntarSelinuxLabel(t *testing.T) {
+	xattrs := map[string]string{
+		"SCHILY.xattr.security.selinux": "invalid-label",
+	}
+	for i, headers := range [][]*tar.Header{
+		{
+			{
+				Name:       "foo",
+				Typeflag:   tar.TypeReg,
+				Mode:       0644,
+				PAXRecords: xattrs,
+			},
+		},
+	} {
+		if err := testBreakout(t, "untar", headers); err != nil {
+			t.Fatalf("i=%d. %v", i, err)
+		}
+	}
+}
+
 func TestUntarInvalidFilenames(t *testing.T) {
 	// TODO Windows: Figure out how to fix this test.
 	if runtime.GOOS == windows {
@@ -943,7 +902,7 @@ func TestUntarInvalidFilenames(t *testing.T) {
 			},
 		},
 	} {
-		if err := testBreakout("untar", "storage-TestUntarInvalidFilenames", headers); err != nil {
+		if err := testBreakout(t, "untar", headers); err != nil {
 			t.Fatalf("i=%d. %v", i, err)
 		}
 	}
@@ -975,7 +934,7 @@ func TestUntarHardlinkToSymlink(t *testing.T) {
 			},
 		},
 	} {
-		if err := testBreakout("untar", "storage-TestUntarHardlinkToSymlink", headers); err != nil {
+		if err := testBreakout(t, "untar", headers); err != nil {
 			t.Fatalf("i=%d. %v", i, err)
 		}
 	}
@@ -1059,7 +1018,7 @@ func TestUntarInvalidHardlink(t *testing.T) {
 			},
 		},
 	} {
-		if err := testBreakout("untar", "storage-TestUntarInvalidHardlink", headers); err != nil {
+		if err := testBreakout(t, "untar", headers); err != nil {
 			t.Fatalf("i=%d. %v", i, err)
 		}
 	}
@@ -1157,14 +1116,14 @@ func TestUntarInvalidSymlink(t *testing.T) {
 			},
 		},
 	} {
-		if err := testBreakout("untar", "storage-TestUntarInvalidSymlink", headers); err != nil {
+		if err := testBreakout(t, "untar", headers); err != nil {
 			t.Fatalf("i=%d. %v", i, err)
 		}
 	}
 }
 
 func TestTempArchiveCloseMultipleTimes(t *testing.T) {
-	reader := ioutil.NopCloser(strings.NewReader("hello"))
+	reader := io.NopCloser(strings.NewReader("hello"))
 	tempArchive, err := NewTempArchive(reader, "")
 	buf := make([]byte, 10)
 	n, err := tempArchive.Read(buf)
@@ -1230,38 +1189,15 @@ func TestReplaceFileTarWrapper(t *testing.T) {
 	}
 }
 
-/*
-// TestPrefixHeaderReadable tests that files that could be created with the
-// version of this package that was built with <=go17 are still readable.
-func TestPrefixHeaderReadable(t *testing.T) {
-	// https://gist.github.com/stevvooe/e2a790ad4e97425896206c0816e1a882#file-out-go
-	var testFile = []byte("\x1f\x8b\x08\x08\x44\x21\x68\x59\x00\x03\x74\x2e\x74\x61\x72\x00\x4b\xcb\xcf\x67\xa0\x35\x30\x80\x00\x86\x06\x10\x47\x01\xc1\x37\x40\x00\x54\xb6\xb1\xa1\xa9\x99\x09\x48\x25\x1d\x40\x69\x71\x49\x62\x91\x02\xe5\x76\xa1\x79\x84\x21\x91\xd6\x80\x72\xaf\x8f\x82\x51\x30\x0a\x46\x36\x00\x00\xf0\x1c\x1e\x95\x00\x06\x00\x00")
-
-	tmpDir, err := ioutil.TempDir("", "prefix-test")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
-	err = Untar(bytes.NewReader(testFile), tmpDir, nil)
-	require.NoError(t, err)
-
-	baseName := "foo"
-	pth := strings.Repeat("a", 100-len(baseName)) + "/" + baseName
-
-	_, err = os.Lstat(filepath.Join(tmpDir, pth))
-	require.NoError(t, err)
-}
-*/
-
 func buildSourceArchive(t *testing.T, numberOfFiles int) (io.ReadCloser, func()) {
-	srcDir, err := ioutil.TempDir("", "storage-test-srcDir")
-	require.NoError(t, err)
+	srcDir := t.TempDir()
 
-	_, err = prepareUntarSourceDirectory(numberOfFiles, srcDir, false)
+	_, err := prepareUntarSourceDirectory(numberOfFiles, srcDir, false)
 	require.NoError(t, err)
 
 	sourceArchive, err := TarWithOptions(srcDir, &TarOptions{})
 	require.NoError(t, err)
 	return sourceArchive, func() {
-		os.RemoveAll(srcDir)
 		sourceArchive.Close()
 	}
 }
@@ -1292,17 +1228,15 @@ func appendModifier(path string, header *tar.Header, content io.Reader) (*tar.He
 }
 
 func readFileFromArchive(t *testing.T, archive io.ReadCloser, name string, expectedCount int, doc string) string {
-	destDir, err := ioutil.TempDir("", "storage-test-destDir")
-	require.NoError(t, err)
-	defer os.RemoveAll(destDir)
+	destDir := t.TempDir()
 
-	err = Untar(archive, destDir, nil)
+	err := Untar(archive, destDir, nil)
 	require.NoError(t, err)
 
-	files, _ := ioutil.ReadDir(destDir)
+	files, _ := os.ReadDir(destDir)
 	assert.Len(t, files, expectedCount, doc)
 
-	content, err := ioutil.ReadFile(filepath.Join(destDir, name))
+	content, err := os.ReadFile(filepath.Join(destDir, name))
 	assert.NoError(t, err)
 	return string(content)
 }
