@@ -3,7 +3,6 @@ package types
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
@@ -47,22 +46,20 @@ func (env rootlessRuntimeDirEnvironmentTest) homedirGet() string {
 }
 
 func TestRootlessRuntimeDir(t *testing.T) {
-	testDir, err := ioutil.TempDir("", "rootless-runtime-dir-test")
-	assert.NilError(t, err)
-	defer os.Remove(testDir)
+	testDir := t.TempDir()
 
 	homeRuntimeDir := filepath.Join(testDir, "home-rundir")
-	err = os.Mkdir(homeRuntimeDir, 0700)
+	err := os.Mkdir(homeRuntimeDir, 0700)
 	assert.NilError(t, err)
 
 	homeRuntimeDisabled := homeRuntimeData{err: errors.New("homedirGetRuntimeDir is disabled")}
 
 	systemdCommandFile := filepath.Join(testDir, "systemd-command")
-	err = ioutil.WriteFile(systemdCommandFile, []byte("systemd"), 0644)
+	err = os.WriteFile(systemdCommandFile, []byte("systemd"), 0644)
 	assert.NilError(t, err)
 
 	initCommandFile := filepath.Join(testDir, "init-command")
-	err = ioutil.WriteFile(initCommandFile, []byte("init"), 0644)
+	err = os.WriteFile(initCommandFile, []byte("init"), 0644)
 	assert.NilError(t, err)
 
 	dirForOwner := filepath.Join(testDir, "dir-for-owner")
@@ -244,12 +241,10 @@ func (rootlessRuntimeDirEnvironmentRace) homedirGet() string {
 }
 
 func TestRootlessRuntimeDirRace(t *testing.T) {
-	raceDir, err := ioutil.TempDir("", "rootless-runtime-dir-race-test")
-	assert.NilError(t, err)
-	defer os.Remove(raceDir)
+	raceDir := t.TempDir()
 
 	procCommandFile := filepath.Join(raceDir, "command")
-	err = ioutil.WriteFile(procCommandFile, []byte("init"), 0644)
+	err := os.WriteFile(procCommandFile, []byte("init"), 0644)
 	assert.NilError(t, err)
 
 	tmpPerUserDir := filepath.Join(raceDir, "tmp")
